function [w0] = make_ic_ch_12(params,I, Vin, Sin, Spin)
% Calculates initial values for variables in the system
% assumes charge from completely discharged
%
% The function calls onto - nobody
% The function is called by run12_BV_ch.m
% 
% Output values are returned as 
% w0=[S8in;S4in;S2in;Sin;Spin;IHin;ILin;Vin;etaHin;etaLin;ENHin;ENLin];
%
% Subject to Creative Commons Attribution 4.0 International Public License
% see license.txt
% (c) Monica Marinescu, 23 Sept 2015, monica.marinescu@imperial.ac.uk

%% Initialise w0 with given values and define useful local constants

w0 = NaN*ones(12,1);
w0(4) = Sin;
w0(5) = Spin;
w0(8) = Vin; 

a = (2*params.R*params.T)./(4*params.F);
b = 2./a;

%% Populate the rest of w0 with calculated values

% corresponding to charged from fully discharged
w0(7) = I;
w0(6) = I - w0(7); % here 0

w0(10) = a * asinh(-w0(7)./(2*params.iLr)); % here 0
w0(12) = Vin-w0(10); % here ENL = V

w0(9) = a * asinh(-w0(6)./(2*params.iHr));
w0(11) = Vin-w0(9);

w0(3) = Sin + Spin;
w0(2) = Sin^2*w0(3)*exp(b*(w0(12)-params.EL0))/0.0665;
w0(1) = w0(2)^2*exp(b*(w0(11)-params.EH0))/0.7294;

%% Check w0

assert(any(isnan(w0))==false,'Initialising w0 has failed')

end