function [w0] = make_ic_disch_12(params,I, Vin, S8in, Spin)
% calculate initial values for variables in the system
% assumes discharge from completely charged
% 
% The function call onto - nobody
% The function is called by run12_BV_disch.m
% 
% output values are returned as 
% w0=[S8in;S4in;S2in;Sin;Spin;IHin;ILin;Vin;etaHin;etaLin;ENHin;ENLin];
%
% Subject to Creative Commons Attribution 4.0 International Public License
% see license.txt
% (c) Monica Marinescu, 23 Sept 2015, monica.marinescu@imperial.ac.uk

%% Initialise w0 with given values and define useful constants

w0 = NaN*ones(12,1);
w0(1) = S8in;
w0(5) = Spin;
w0(8) = Vin;

%% Populate the rest of w0 with calculated values

% corresponding to discharge from fully charged
w0(6) = I;

w0(9) = asinh(-w0(6)/2/params.iHr)/4/params.F*2*params.R*params.T; %FIXIT
w0(11) = Vin-w0(9);
w0(2) = sqrt(0.7294*S8in/exp((w0(11)-params.EH0)/params.R/params.T*4*params.F));


w0(7) = I - w0(6); % here 0

w0(10) = asinh(-w0(7)/2/params.iLr)/4/params.F*2*params.R*params.T; % here 0
w0(12) = Vin-w0(10); % here ENL = V
Sintemp = nthroot(0.0665*w0(2)/exp(4*params.F/params.R/params.T*(w0(12)-params.EL0)),3);

myfun = @(x) x^2*(x+Spin)-Sintemp^3; 

x = fzero(myfun, Sintemp);

w0(4) = x;
w0(3) = w0(4) + Spin;

%% Check w0

assert(any(isnan(w0))==false,'Initialising w0 has failed')

end